@@ -83,10 +83,10 @@ def _get_help_record(opt: click.Option) -> ty.Tuple[str, str]:
         # Starting from Click 7.0 show_default can be a string. This is
         # mostly useful when the default is not a constant and
         # documentation thus needs a manually written string.
-        extras.append(':default: %s' % opt.show_default)
+        extras.append(':default: ``%s``' % opt.show_default)
     elif opt.default is not None and opt.show_default:
         extras.append(
-            ':default: %s'
+            ':default: ``%s``'
             % (
                 ', '.join(str(d) for d in opt.default)
                 if isinstance(opt.default, (list, tuple))
